==> haskell-doctest-discover-0.2.0.0-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-discover.sh <==
#!/bin/sh
export PATH='/build/haskell-doctest-discover/src/doctest-discover-04b6b1f9fa93518e49d7a95052e6efc2d2d2dabe/dist/build/doctest-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/build/haskell-doctest-discover/src/doctest-discover-04b6b1f9fa93518e49d7a95052e6efc2d2d2dabe/dist/build/doctest-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:               doctest-discover
version:            0.2.0.0
visibility:         public
id:                 doctest-discover-0.2.0.0-KBtG6RSJBmYACDSixKXPJD
key:                doctest-discover-0.2.0.0-KBtG6RSJBmYACDSixKXPJD
license:            LicenseRef-PublicDomain
maintainer:         karun012@gmail.com
author:             Karun Ramakrishnan
homepage:           http://github.com/karun012/doctest-discover
synopsis:           Easy way to run doctests via cabal
description:
    doctest-discover provides an easy way to run doctests via cabal

category:           Testing
abi:                6f78e70309fb6303857b6a05d0c7aa3c
exposed:            True
data-dir:           /usr/share/haskell-doctest-discover
depends:
    aeson-2.2.0.0-A8FqDK4tVym6hhqwC7qXFC base-4.18.2.1
    bytestring-0.11.5.3 directory-1.3.8.5
    doctest-0.22.3-KB5BxWUSLlI8Oxy9ibeYC7 filepath-1.4.300.1

haddock-interfaces:
    /usr/share/doc/haskell-doctest-discover/html/doctest-discover.haddock

haddock-html:       /usr/share/doc/haskell-doctest-discover/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-discover-0.2.0.0-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-discover.sh <==
#!/bin/sh
export PATH='/build/haskell-doctest-discover/src/doctest-discover-04b6b1f9fa93518e49d7a95052e6efc2d2d2dabe/dist/build/doctest-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/build/haskell-doctest-discover/src/doctest-discover-04b6b1f9fa93518e49d7a95052e6efc2d2d2dabe/dist/build/doctest-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:               doctest-discover
version:            0.2.0.0
visibility:         public
id:                 doctest-discover-0.2.0.0-KZA5Qkp3V6kI94inZlNl7U
key:                doctest-discover-0.2.0.0-KZA5Qkp3V6kI94inZlNl7U
license:            LicenseRef-PublicDomain
maintainer:         karun012@gmail.com
author:             Karun Ramakrishnan
homepage:           http://github.com/karun012/doctest-discover
synopsis:           Easy way to run doctests via cabal
description:
    doctest-discover provides an easy way to run doctests via cabal

category:           Testing
abi:                6f78e70309fb6303857b6a05d0c7aa3c
exposed:            True
data-dir:           /usr/share/haskell-doctest-discover
depends:
    aeson-2.2.0.0-4qLATSA6nfj1RfgXH6DMKK base-4.18.2.1
    bytestring-0.11.5.3 directory-1.3.8.5
    doctest-0.22.3-A0mxxRsH5032R7i5gr3ZcV filepath-1.4.300.1

haddock-interfaces:
    /usr/share/doc/haskell-doctest-discover/html/doctest-discover.haddock

haddock-html:       /usr/share/doc/haskell-doctest-discover/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
